pub fn clean(
text: Option<&str>,
html: Option<&str>,
config: &ReaderConfig,
) -> ReaderOutputExpand description
Run the full reader pipeline on a message body.
Accepts either plain text or HTML. If HTML, converts to plain text first.
pub fn clean(
text: Option<&str>,
html: Option<&str>,
config: &ReaderConfig,
) -> ReaderOutputRun the full reader pipeline on a message body.
Accepts either plain text or HTML. If HTML, converts to plain text first.